<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>FileOps</name>
    <message>
        <location filename="../fileops.cpp" line="93"/>
        <location filename="../fileops.cpp" line="133"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="94"/>
        <location filename="../fileops.cpp" line="134"/>
        <source>Destination directory doesn&apos;t exist</source>
        <translation>Cartella di destinazione</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="137"/>
        <source>Move Files</source>
        <translation>Sposta file</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileops.cpp" line="138"/>
        <source>Are you sure you want to move %n file(s)?</source>
        <translation>
            <numerusform>Vuoi davvero spostare %n file?</numerusform>
            <numerusform>Vuoi davvero spostare %n file?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="154"/>
        <source>Copying</source>
        <translation>Copia</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="155"/>
        <location filename="../fileops.cpp" line="249"/>
        <source>Stop</source>
        <translation>Ferma</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="200"/>
        <source>Copying file %1/%2</source>
        <translation>Copia in corso del file %1/%2</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="248"/>
        <source>Moving</source>
        <translation>Spostamento</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="284"/>
        <source>Moving file %1/%2</source>
        <translation>Spostamento del file %1/%2</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="109"/>
        <source>Remove Files</source>
        <translation>Rimozione file</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileops.cpp" line="110"/>
        <source>Are you sure you want to remove %n file(s) from disk?</source>
        <translation>
            <numerusform>Vuoi davvero rimuovere %n file dal disco?</numerusform>
            <numerusform>Vuoi davvero rimuovere %n file dal disco?</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>FileOpsFactory</name>
    <message>
        <location filename="../fileopsfactory.cpp" line="30"/>
        <source>File Operations Plugin</source>
        <translation>Estensione per le operazioni su file</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="50"/>
        <source>About File Operations Plugin</source>
        <translation>Informazioni sull&apos;estensione per le operazioni su file</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="51"/>
        <source>Qmmp File Operations Plugin</source>
        <translation>Estensione per le operazioni su file di Qmmp</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Autori: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>HotkeyDialog</name>
    <message>
        <location filename="../hotkeydialog.ui" line="14"/>
        <source>Modify Shortcut</source>
        <translation>Modifica scorciatoia</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="29"/>
        <source>Press the key combination you want to assign</source>
        <translation>Premi la combinazione di tasti che vuoi assegnare</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="43"/>
        <source>Clear</source>
        <translation>Pulisci</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>File Operations Settings</source>
        <translation>Impostazioni per le operazioni su file</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Enabled</source>
        <translation>Abilitato</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="53"/>
        <source>Operation</source>
        <translation>Operazione</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>Menu text</source>
        <translation>Menu testo</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Shortcut</source>
        <translation>Scorciatoia</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="79"/>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="92"/>
        <location filename="../settingsdialog.cpp" line="54"/>
        <location filename="../settingsdialog.cpp" line="134"/>
        <source>Remove</source>
        <translation>Rimuovi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="116"/>
        <source>Destination:</source>
        <translation>Destinazione:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="126"/>
        <location filename="../settingsdialog.ui" line="143"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="133"/>
        <source>File name pattern:</source>
        <translation>Schema nome del file:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="51"/>
        <location filename="../settingsdialog.cpp" line="131"/>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="52"/>
        <location filename="../settingsdialog.cpp" line="132"/>
        <source>Rename</source>
        <translation>Rinomina</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="53"/>
        <location filename="../settingsdialog.cpp" line="133"/>
        <source>Move</source>
        <translation>Sposta</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="137"/>
        <source>New action</source>
        <translation>Nuova azione</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="232"/>
        <source>Choose a directory</source>
        <translation>Scegli una cartella</translation>
    </message>
</context>
</TS>
